Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type PlayerInfo ¶
A PlayerInfo contains information about player counts on a Rust server and methods to read it's state
type Querier ¶
type Querier struct {
ServerConfig
Name string
PlayerInfo PlayerInfo
// contains filtered or unexported fields
}
A Querier queries and contains information about a Rust server
func NewQuerier ¶
func NewQuerier(server ServerConfig) (*Querier, error)
NewQuerier creats a new Server for observing a Rust server
func (*Querier) AddListener ¶
func (sq *Querier) AddListener(l chan QueryResult)
type QueryProvider ¶
type QueryProvider interface {
QueryInfo() (*valve.ServerInfo, error)
Close()
}
type QueryResult ¶
type QueryResult struct {
Online bool
Timestamp time.Time
PlayerInfo
}
type ServerConfig ¶
A ServerConfig is the connection information for a Rust server
Click to show internal directories.
Click to hide internal directories.